@@ -1,5 +1,8 @@
 package org.gcube.applicationsupportlayer.social.mailing;
 
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
 import java.util.Date;
 import java.util.Properties;
 
@@ -10,10 +13,11 @@ import javax.mail.Transport;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
 
-import org.gcube.common.core.utils.logging.GCUBEClientLog;
 import org.gcube.portal.custom.communitymanager.OrganizationsUtil;
 import org.gcube.portal.databook.shared.Notification;
 import org.gcube.portal.databook.shared.NotificationType;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.liferay.portal.model.UserModel;
 import com.liferay.portal.service.UserLocalServiceUtil;
@@ -25,8 +29,9 @@ import com.liferay.portal.util.PortalUtil;
  *
  */
 public class EmailPlugin {
-	private static GCUBEClientLog _log = new GCUBEClientLog(EmailPlugin.class);
 
+	private static final Logger _log = LoggerFactory.getLogger(EmailPlugin.class);
+	
 	private static String getHTMLEmail(Notification notification2Save, String userFirstName, String portalURL, String email) {
 
 		String removedMarkup = notification2Save.getDescription().replaceAll("&amp;", "&");
@@ -73,7 +78,7 @@ public class EmailPlugin {
 		return completeActonLinkByNotificationType(notification2Save, actionLink, portalURL);
 	}
 
-	public static void sendNotification(Notification notification2Save, String vreName) {
+	public static void sendNotification(Notification notification2Save, String vreName, String portalName, String senderEmail) {
 
 		UserModel user = null;
 		String portalUrl = null;
@@ -96,15 +101,14 @@ public class EmailPlugin {
 
 		try {
 			// EMAIL SENDER
-			Address from = new InternetAddress("no-reply@d4science.org");
+			Address from = new InternetAddress(senderEmail, portalName);
+		    mimeMessage.setHeader("Content-Type", "text/html; charset=UTF-8");
 			mimeMessage.setFrom(from);
-
 			Address address = new InternetAddress(email);
 			mimeMessage.addRecipient(Message.RecipientType.TO, address);
 
-			mimeMessage.setSubject(getSubjectByNotificationType(notification2Save, portalUrl, vreName));
-			// mimeMessage.setText(body);
-			mimeMessage.setContent(getHTMLEmail(notification2Save, user.getFirstName(), portalUrl, email), "text/html");
+			mimeMessage.setSubject(getSubjectByNotificationType(notification2Save, portalUrl, vreName, user.getFirstName()));
+			mimeMessage.setContent(getHTMLEmail(notification2Save, user.getFirstName(), portalUrl, email), "text/html; charset=UTF-8");
 			mimeMessage.setSentDate(new Date());
 			Transport.send(mimeMessage);
 			_log.trace("notification email sent successfully");
@@ -113,60 +117,65 @@ public class EmailPlugin {
 			_log.error("While sending the notification email:", e);
 		}
 	}
-
-	private static String getSubjectByNotificationType(Notification notification2Save, String portalURL, String vreName) {
-		//<Portal URI senza protocollo>: Shared document workflow view notification
-		String portalHost = portalURL.replaceAll("https://", "");
-		portalHost = portalHost.replaceAll("http://", "");
+	/**
+	 * construct the subjec of the email
+	 * @param notification2Save
+	 * @param portalURL
+	 * @param vreName
+	 * @return
+	 */
+	private static String getSubjectByNotificationType(Notification notification2Save, String portalURL, String vreName, String userFirstName) {
 		switch (notification2Save.getType()) {
 		case LIKE:
-			return portalHost + ": Like on your post notification";
+			return notification2Save.getSenderFullName()+" favorited your post";
 		case COMMENT:
-			return portalHost + ": Reply on a post notification";
+			return notification2Save.getSenderFullName()+" commented on the post";
 		case MESSAGE:
-			return portalHost + ": New message notification";
+			return notification2Save.getSenderFullName()+ " sent you a message";
 		case WP_FOLDER_ADDEDUSER:
-			return portalHost + ": New user in a shared folder notification";
+			return "New user in a shared folder";
 		case WP_FOLDER_REMOVEDUSER:
-			return portalHost + ": Removed user in a shared folder notification";
+			return "Removed user in a shared folder";
 		case WP_FOLDER_SHARE:
-			return portalHost + ": Folder sharing notification";
+			return "Folder sharing notification";
 		case WP_ITEM_NEW:
-			return portalHost + ": New item in a shared folder notification";
+			return "New item in a shared folder";
 		case WP_ITEM_DELETE:
-			return portalHost + ": Deleted item in a shared folder notification";
+			return "Deleted item in a shared folder";
 		case WP_ITEM_UPDATED:
-			return portalHost + ": Updated item in a shared folder notification";
+			return "Updated item in a shared folder";
 		case OWN_COMMENT:
-			return portalHost + ": Reply on your post notification";
+			return notification2Save.getSenderFullName() + " commented on your post";
 		case MENTION:
-			return portalHost + ": Mention in a post notification";
+			return notification2Save.getSenderFullName() + " mentioned you";
+		case POST_ALERT:
+			return notification2Save.getSenderFullName() + " shared a news on " + vreName;
 		case REQUEST_CONNECTION:
-			return portalHost + ": Connection request notification";
+			return "Connection request";
 		case JOB_COMPLETED_NOK:
-			return portalHost + ": Job Completed notification";
+			return "Job Completed";
 		case JOB_COMPLETED_OK:
-			return portalHost + ": Job Completed notification";
+			return "Job Completed";
 		case DOCUMENT_WORKFLOW_EDIT:
-			return portalHost + ": Shared document workflow view notification";
+			return "Shared document workflow view";
 		case DOCUMENT_WORKFLOW_VIEW:
-			return portalHost + ": Shared document workflow view notification";
+			return "Shared document workflow view";
 		case DOCUMENT_WORKFLOW_STEP_REQUEST_TASK:
-			return portalHost + " - " + vreName +": Request for task notification";
+			return vreName +": Request for task";
 		case DOCUMENT_WORKFLOW_FIRST_STEP_REQUEST_INVOLVMENT:
-			return portalHost + " - " + vreName +": Request for task notification";
+			return vreName +": Request for task";
 		case DOCUMENT_WORKFLOW_USER_FORWARD_TO_OWNER:
-			return portalHost + " - " + vreName +": Document workflow forward notification";
+			return vreName +": Document workflow forward";
 		case DOCUMENT_WORKFLOW_STEP_FORWARD_PEER:
-			return portalHost + " - " + vreName +": Done task notification";
+			return vreName +": Done task notification";
 		case DOCUMENT_WORKFLOW_FORWARD_STEP_COMPLETED_OWNER:
-			return portalHost + " - " + vreName +": Document workflow step completion notification";
+			return vreName +": Document workflow step completion";
 		case CALENDAR_ADDED_EVENT:
-			return portalHost + " - " + vreName +": New event in a shared calendar notification";
+			return vreName +": New event in a shared calendar";
 		case CALENDAR_UPDATED_EVENT:
-			return portalHost + " - " + vreName +": Edited event in a shared calendar notification";
+			return vreName +": Edited event in a shared calendar";
 		case CALENDAR_DELETED_EVENT:
-			return portalHost + " - " + vreName +": Deleted in a shared calendar notification";
+			return vreName +": Deleted in a shared calendar";
 		default:
 			return "You have a new Notification";
 		}
@@ -217,6 +226,9 @@ public class EmailPlugin {
 		case OWN_COMMENT:
 			actionLink.append("\">.").append(" See the Post").append("</a>");
 			break;
+		case POST_ALERT:
+			actionLink.append("\">").append("See this News").append("</a>");
+			break;
 		case REQUEST_CONNECTION:
 			actionLink.append("\">.").append(" Go to Contacts Center").append("</a>");
 			break;
@@ -247,6 +259,15 @@ public class EmailPlugin {
 		case DOCUMENT_WORKFLOW_FORWARD_STEP_COMPLETED_OWNER:
 			actionLink.append("\">.").append(" Go to Document Workflow Manager").append("</a>");
 			break;
+		case CALENDAR_ADDED_EVENT:
+			actionLink.append("\">.").append(" Go to Calendar").append("</a>");
+			break;
+		case CALENDAR_UPDATED_EVENT:
+			actionLink.append("\">.").append(" Go to Calendar").append("</a>");
+			break;
+		case CALENDAR_DELETED_EVENT:
+			actionLink.append("\">.").append(" Go to Calendar").append("</a>");
+			break;
 		default:
 			actionLink.append("\">.").append("").append("</a>");
 			break;			
@@ -254,6 +275,7 @@ public class EmailPlugin {
 		
 		return actionLink.toString();
 	}
+		
 }
 
 
